@@ -40,7 +40,7 @@
 (defvar cvs-version
   (ignore-errors
     (with-temp-buffer
-      (call-process "cvs" nil t nil "-v")
+      (call-process cvs-program nil t nil "-v")
       (goto-char (point-min))
       (when (re-search-forward "(CVS) \\([0-9]+\\)\\.\\([0-9]+\\)" nil t)
 	(cons (string-to-number (match-string 1))
@@ -104,7 +104,7 @@ Else, they will never be automatically removed from the *cvs* buffer."
 
 (defcustom cvs-auto-remove-directories 'handled
   "*If ALL, directory entries will never be shown.
-If HANLDED, only non-handled directories will be shown.
+If HANDLED, only non-handled directories will be shown.
 If EMPTY, only non-empty directories will be shown."
   :group 'pcl-cvs
   :type '(choice (const :tag "No" nil) (const all) (const handled) (const empty)))
@@ -137,7 +137,7 @@ current line.  See also `cvs-ignore-marks'"
   :type '(boolean))
 
 (defvar cvs-diff-ignore-marks t
-  "Obsolete variable: use cvs-ignore-marks instead.")
+  "Obsolete: use `cvs-invert-ignore-marks' instead.")
 
 (defcustom cvs-invert-ignore-marks
   (let ((l ()))
@@ -158,7 +158,7 @@ in `cvs-default-ignore-marks'."
   "*Ask for confirmation before removing files.
 Non-nil means that PCL-CVS will ask confirmation before removing files
 except for files whose content can readily be recovered from the repository.
-A value of LIST means that the list of files to be deleted will be
+A value of `list' means that the list of files to be deleted will be
 displayed when asking for confirmation."
   :group 'pcl-cvs
   :type '(choice (const list)
@@ -167,7 +167,7 @@ displayed when asking for confirmation."
 
 (defcustom cvs-add-default-message nil
   "*Default message to use when adding files.
-If set to NIL, `cvs-mode-add' will always prompt for a message."
+If set to nil, `cvs-mode-add' will always prompt for a message."
   :group 'pcl-cvs
   :type '(choice (const :tag "Prompt" nil)
 		 (string)))
@@ -352,13 +352,13 @@ This variable is buffer local and only used in the *cvs* buffer.")
     (("0" "1" "2" "3" "4" "5" "6" "7" "8" "9") . digit-argument)
     ("-" .	negative-argument)
     ;; various
-    (undo .	cvs-mode-undo)
+    ;; (undo .	cvs-mode-undo)
     ("?" .	cvs-help)
     ("h" .	cvs-help)
     ("q" .	cvs-bury-buffer)
-    ;;("Q" .	kill-buffer)
+    ("z" .	kill-this-buffer)
     ("F" .	cvs-mode-set-flags)
-    ("\M-f" .	cvs-mode-force-command)
+    ("!" .	cvs-mode-force-command)
     ("\C-c\C-c" . cvs-mode-kill-process)
     ;; marking
     ("m" .	cvs-mode-mark)
@@ -398,6 +398,7 @@ This variable is buffer local and only used in the *cvs* buffer.")
     ("c" .	cvs-mode-commit)
     ("e" .	cvs-mode-examine)
     ("f" .	cvs-mode-find-file)
+    ("\C-m" .	cvs-mode-find-file)
     ("i" .	cvs-mode-ignore)
     ("l" .	cvs-mode-log)
     ("o" .	cvs-mode-find-file-other-window)
@@ -409,6 +410,7 @@ This variable is buffer local and only used in the *cvs* buffer.")
     ;; cvstree bindings
     ("+" .	cvs-mode-tree)
     ;; mouse bindings
+    ([mouse-2] . cvs-mode-find-file)
     ([(down-mouse-3)] . cvs-menu)
     ;; Emacs-21 toolbar
     ;;([tool-bar item1] . (menu-item "Examine" cvs-examine :image (image :file "/usr/share/icons/xpaint.xpm" :type xpm)))
